#ifndef SETTINGS_H
#define SETTINGS_H

#include <QDialog>

namespace Ui {
    class Settings;
}

class Settings : public QDialog
{
    Q_OBJECT

public:
    explicit Settings(QWidget *parent = 0);
    ~Settings();

private slots:

    void on_checkBoxSecureSetting_clicked();

    void on_checkBoxWakeScr_clicked();

    void on_checkBoxAudio_clicked();

    void on_checkBoxVibra_clicked();

    void on_checkBoxSpeech_clicked();

    void on_horizontalSlider_valueChanged(int value);

    void on_pushButtonSave_clicked();

    void on_pushButtonDefault_clicked();

    void on_checkBoxGeneralSetting_clicked();

    void on_pushButtonMinusTen_clicked();

    void on_pushButtonMinusOne_clicked();

    void on_pushButtonPlusOne_clicked();

    void on_pushButtonPlusTen_clicked();

private:
    Ui::Settings *ui;
};

#endif // SETTINGS_H
